summaryrefslogtreecommitdiff
path: root/src/mongo/client/authenticate.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/client/authenticate.h')
-rw-r--r--src/mongo/client/authenticate.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/mongo/client/authenticate.h b/src/mongo/client/authenticate.h
index 1aac7719f00..7b841b2ee84 100644
--- a/src/mongo/client/authenticate.h
+++ b/src/mongo/client/authenticate.h
@@ -136,7 +136,7 @@ Future<void> authenticateClient(const BSONObj& params,
* but the __system user's credentials will be filled in automatically.
*
* The "mechanismHint" parameter will force authentication with a specific mechanism
* (e.g. SCRAM-SHA-256). If it is boost::none, then a "hello" will be called to negotiate
* a SASL mechanism with the server.
*
* The "stepDownBehavior" parameter controls whether replication will kill the connection on
@@ -168,7 +168,7 @@ BSONObj buildAuthParams(StringData dbname,
StringData mechanism);
/**
* Run a "hello" exchange to negotiate a SASL mechanism for authentication.
*/
Future<std::string> negotiateSaslMechanism(RunCommandHook runCommand,
const UserName& username,
@@ -195,19 +195,19 @@ enum class SpeculativeAuthType {
};
/**
* Constructs a "speculativeAuthenticate" or "speculativeSaslStart" payload for an "hello" request
* based on a given URI.
*/
-SpeculativeAuthType speculateAuth(BSONObjBuilder* helloRequestBuilder,
+SpeculativeAuthType speculateAuth(BSONObjBuilder* isMasterRequest,
const MongoURI& uri,
std::shared_ptr<SaslClientSession>* saslClientSession);
/**
* Constructs a "speculativeAuthenticate" or "speculativeSaslStart" payload for an "hello" request
* using internal (intracluster) authentication.
*/
SpeculativeAuthType speculateInternalAuth(const HostAndPort& remoteHost,
- BSONObjBuilder* helloRequestBuilder,
+ BSONObjBuilder* isMasterRequest,
std::shared_ptr<SaslClientSession>* saslClientSession);
} // namespace auth
@@ -136,7 +136,7 @@ Future<void> authenticateClient(const BSONObj& params,
*
* The "mechanismHint" parameter will force authentication with a specific mechanism
- * (e.g. SCRAM-SHA-256). If it is boost::none, then a "hello" will be called to negotiate
+ * (e.g. SCRAM-SHA-256). If it is boost::none, then an isMaster will be called to negotiate
* a SASL mechanism with the server.
*
@@ -168,7 +168,7 @@ BSONObj buildAuthParams(StringData dbname,
StringData mechanism);
/**
- * Run a "hello" exchange to negotiate a SASL mechanism for authentication.
+ * Run an isMaster exchange to negotiate a SASL mechanism for authentication.
*/
Future<std::string> negotiateSaslMechanism(RunCommandHook runCommand,
@@ -195,19 +195,19 @@ enum class SpeculativeAuthType {
};
/**
- * Constructs a "speculativeAuthenticate" or "speculativeSaslStart" payload for an "hello" request
- * based on a given URI.
+ * Constructs a "speculativeAuthenticate" or "speculativeSaslStart"
+ * payload for an isMaster request based on a given URI.
*/
@@ -195,19 +195,19 @@ enum class SpeculativeAuthType {
std::shared_ptr<SaslClientSession>* saslClientSession);
/**
- * Constructs a "speculativeAuthenticate" or "speculativeSaslStart" payload for an "hello" request
- * using internal (intracluster) authentication.
+ * Constructs a "speculativeAuthenticate" or "speculativeSaslStart"
+ * payload for an isMaster request using internal (intracluster) authentication.
*/
SpeculativeAuthType speculateInternalAuth(const HostAndPort& remoteHost,